@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  *
@@ -10,7 +10,7 @@
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <grantlee/templateloader.h>
 #else
-#include <KTextTemplate/templateloader.h>
+#include <KTextTemplate/TemplateLoader>
 #endif
 
 namespace KCalUtils
